pub struct InterpreterCache<'a> { /* private fields */ }Expand description
A cache used by the interpreter.
Ideally, such a cache should be constructed once per PDF and then reused across multiple interpreter invocations on the same document.
Implementations
Sourceimpl<'a> InterpreterCache<'a>
impl<'a> InterpreterCache<'a>