RasterImage

Struct RasterImage 

pub struct RasterImage<'a>(/* private fields */);
A raster image.

Implementations

Source

impl RasterImage<'_>

pub fn with_rgba( &self, func: impl FnOnce(ImageData, Option<LumaData>), target_dimension: Option<(u32, u32)>, )

Perform some operation with the RGB and alpha channel of the image.

The second argument allows you to give the image decoder a hint for what resolution of the image you want to have. Note that this does not mean that the resulting image will have that dimension. Instead, it allows the image decoder to extract a lower-resolution version of the image in certain cases.

pub fn stream(&self) -> &Stream<'_>

Return the underlying stream object.

This allows you to get access to the raw encoded image data, without doing any decoding.